@@ -229,11 +229,13 @@ void calendarDialog::addToCalendar()
         QMaemo5InformationBox::information(parent, tr("<br>Entry is in the past!<br>"), QMaemo5InformationBox::DefaultTimeout);
     } else
     {
+
         /*
         qDebug() <<title;
         qDebug() <<tsFrom.toString("dd.MM.yyyy hh:mm");
         qDebug() <<tsTo.toString("dd.MM.yyyy hh:mm");
         qDebug() <<description;
+        qDebug() <<calendar->getCalendarId();
         */
 
         CEvent *pEvent = new CEvent(title.toStdString(), description.toStdString(), "", tsFrom.toTime_t(), tsTo.toTime_t());
@@ -241,7 +243,14 @@ void calendarDialog::addToCalendar()
 
         CMulticalendar *multiCalendar = CMulticalendar::MCInstance();
         multiCalendar->addEvent(pEvent, calendar->getCalendarId(), errorCode);
-        QMaemo5InformationBox::information(parent, tr("<br>Entry added to the ") + handlePrivateCalTranslation(QString::fromStdString(calendar->getCalendarName())) + tr(" calendar.<br>"), QMaemo5InformationBox::DefaultTimeout);
+        if (errorCode == CALENDAR_OPERATION_SUCCESSFUL)
+        {
+            QMaemo5InformationBox::information(parent, tr("<br>Entry added to the ") + handlePrivateCalTranslation(QString::fromStdString(calendar->getCalendarName())) + tr(" calendar.<br>"), QMaemo5InformationBox::DefaultTimeout);
+        } else if (errorCode == CALENDAR_ENTRY_DUPLICATED){
+            QMaemo5InformationBox::information(parent, tr("<br>Entry already exists!<br>"), QMaemo5InformationBox::DefaultTimeout);
+        } else {
+            QMaemo5InformationBox::information(parent, tr("<br>An error occured while adding the entry!<br>"), QMaemo5InformationBox::DefaultTimeout);
+        }
     }
 
     close();
