@@ -52,9 +52,8 @@
         <translation>Uhrzeit</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="190"/>
         <source>- bahn.de: fixed crash problem&lt;br&gt;- optimized calendar selection screen&lt;br&gt;- arrival/departue selector changed to toggle button.</source>
-        <translation>- bahn.de: absturz problem behoben&lt;br&gt;- kalender auswahl verbessert&lt;br&gt;- abfahrt/ankuft knopf verbessert</translation>
+        <translation type="obsolete">- bahn.de: absturz problem behoben&lt;br&gt;- kalender auswahl verbessert&lt;br&gt;- abfahrt/ankuft knopf verbessert</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="286"/>
@@ -153,6 +152,11 @@
         <source>Select target calendar</source>
         <translation type="obsolete">Ziel Kalender wählen</translation>
     </message>
+    <message>
+        <location filename="mainwindow.cpp" line="190"/>
+        <source>- sbb.ch: fixed parser</source>
+        <translation>- sbb.ch: fehler im parser behoben</translation>
+    </message>
     <message>
         <location filename="mainwindow.cpp" line="314"/>
         <source>Thank you for Donating!</source>
@@ -281,6 +285,16 @@
 
 (hinzugefuegt von Fahrplan, bitte vor Fahrantritt daten erneut pruefen)</translation>
     </message>
+    <message>
+        <location filename="calendardialog.cpp" line="250"/>
+        <source>&lt;br&gt;Entry already exists!&lt;br&gt;</source>
+        <translation>&lt;br&gt;Eintrag existiert bereits!&lt;br&gt;</translation>
+    </message>
+    <message>
+        <location filename="calendardialog.cpp" line="252"/>
+        <source>&lt;br&gt;An error occured while adding the entry!&lt;br&gt;</source>
+        <translation>&lt;br&gt;Beim hinzufügen ist ein Fehler aufgetreten!&lt;br&gt;</translation>
+    </message>
     <message>
         <location filename="calendardialog.cpp" line="98"/>
         <location filename="calendardialog.cpp" line="229"/>
@@ -288,12 +302,12 @@
         <translation>&lt;br&gt;Eintrag ist in der Vergangenheit!&lt;br&gt;</translation>
     </message>
     <message>
-        <location filename="calendardialog.cpp" line="244"/>
+        <location filename="calendardialog.cpp" line="248"/>
         <source>&lt;br&gt;Entry added to the </source>
         <translation>&lt;br&gt;Eintrag wurde zum </translation>
     </message>
     <message>
-        <location filename="calendardialog.cpp" line="244"/>
+        <location filename="calendardialog.cpp" line="248"/>
         <source> calendar.&lt;br&gt;</source>
         <translation> Kalender hinzugefügt.&lt;br&gt;</translation>
     </message>
