@@ -187,7 +187,7 @@ MainWindow::MainWindow(QWidget *parent)
     {
         QMessageBox::about(this,
                            tr("Welcome to a new version of fahrplan this has changed"),
-                           tr("- bahn.de: fixed crash problem<br>- optimized calendar selection screen<br>- arrival/departue selector changed to toggle button.")
+                           tr("- sbb.ch: fixed parser")
                            );
 
         settings->setValue("firstLaunch", APP_VER);
