@@ -211,12 +211,12 @@ DetailResultInfo parserSbbCh::getJourneyDetailsData(QString queryUrl)
 
     //qDebug() <<filebuffer->buffer();
 
-    QRegExp regexp = QRegExp("</form>(.*)&nbsp;&nbsp;Details - Connection(.*)<table class=\"hac_greybox\">(.*)</table>(.*)<table style=\"height:");
+    QRegExp regexp = QRegExp("</form>(.*)Details - Connection(.*)<table class=\"hac_greybox\">(.*)<table class=\"buttons\"");
     regexp.setMinimal(true);
 
     regexp.indexIn(filebuffer->buffer());
 
-    QString element = "<html xmlns=\"http://www.w3.org/1999/xhtml\">\n<body>\n<table>" + regexp.cap(3) + "</table></td></tr></table>\n</body>\n</html>\n";
+    QString element = "<html xmlns=\"http://www.w3.org/1999/xhtml\">\n<body>\n<table>" + regexp.cap(3) + "</td></tr></table>\n</body>\n</html>\n";
 
     //Clean HTML or fix other not needed but parse error causing stuff
     element.replace(" nowrap ", " nowrap=\"true\" ");
@@ -230,6 +230,11 @@ DetailResultInfo parserSbbCh::getJourneyDetailsData(QString queryUrl)
     element.replace(imgReg, "alt=\"\\1\" />");
     element.replace("&nbsp;", " ");
 
+    QRegExp detailIdReg = QRegExp("id=\"linkDtlClose(.*)\"");
+    detailIdReg.setMinimal(true);
+    detailIdReg.indexIn(element);
+    QString detailId = detailIdReg.cap(1);
+
 //    qDebug() <<element;
 
     QBuffer readBuffer;
@@ -239,14 +244,14 @@ DetailResultInfo parserSbbCh::getJourneyDetailsData(QString queryUrl)
     QXmlQuery query;
     query.bindVariable("path", &readBuffer);
     //Query for more than one result
-    query.setQuery("declare default element namespace \"http://www.w3.org/1999/xhtml\"; declare variable $path external; doc($path)/html/body/table/tr/td/table/tr/td[@headers='time-0'][@class!='prognosis'][@class!='prognosis last']/string()");
+    query.setQuery("declare default element namespace \"http://www.w3.org/1999/xhtml\"; declare variable $path external; doc($path)/html/body/table/tr/td/table/tr/td[@headers='time-" + detailId + "']/string()");
     QStringList timelinkResults;
     if (!query.evaluateTo(&timelinkResults))
     {
         qDebug() << "parserSbbCh::getJourneyDetailsData - Query 1 Failed";
     }
 
-    query.setQuery("declare default element namespace \"http://www.w3.org/1999/xhtml\"; declare variable $path external; doc($path)/html/body/table/tr/td/table/tr/td[@headers='products-0']/string()");
+    query.setQuery("declare default element namespace \"http://www.w3.org/1999/xhtml\"; declare variable $path external; doc($path)/html/body/table/tr/td/table/tr/td[@headers='products-" + detailId + "']/string()");
 
     QStringList trainsResults;
     if (!query.evaluateTo(&trainsResults))
@@ -254,7 +259,7 @@ DetailResultInfo parserSbbCh::getJourneyDetailsData(QString queryUrl)
         qDebug() << "parserSbbCh::getJourneyDetailsData - Query 2 Failed";
     }
 
-    query.setQuery("declare default element namespace \"http://www.w3.org/1999/xhtml\"; declare variable $path external; doc($path)/html/body/table/tr/td/table/tr/td[@headers='stops-0']/a[@title]/string()");
+    query.setQuery("declare default element namespace \"http://www.w3.org/1999/xhtml\"; declare variable $path external; doc($path)/html/body/table/tr/td/table/tr/td[@class!='stop-station-icon noPrint'][@class!='stop-station-icon noPrint last'][@headers='stops-" + detailId + "']/a/string()");
 
     QStringList fromToResults;
     if (!query.evaluateTo(&fromToResults))
@@ -278,7 +283,7 @@ DetailResultInfo parserSbbCh::getJourneyDetailsData(QString queryUrl)
         qDebug() << "parserSbbCh::getJourneyDetailsData - Query 5 Failed";
     }
 
-    query.setQuery("declare default element namespace \"http://www.w3.org/1999/xhtml\"; declare variable $path external; doc($path)/html/body/table/tr/td/table/tr/td[@headers='platform-0']/string()");
+    query.setQuery("declare default element namespace \"http://www.w3.org/1999/xhtml\"; declare variable $path external; doc($path)/html/body/table/tr/td/table/tr/td[@headers='platform-" + detailId + "']/string()");
 
     QStringList platformResults;
     if (!query.evaluateTo(&platformResults))
@@ -286,7 +291,7 @@ DetailResultInfo parserSbbCh::getJourneyDetailsData(QString queryUrl)
         qDebug() << "parserSbbCh::getJourneyDetailsData - Query 6 Failed";
     }
 
-    query.setQuery("declare default element namespace \"http://www.w3.org/1999/xhtml\"; declare variable $path external; doc($path)/html/body/table/tr/td/table/tr/td[@headers='date-0']/string()");
+    query.setQuery("declare default element namespace \"http://www.w3.org/1999/xhtml\"; declare variable $path external; doc($path)/html/body/table/tr/td/table/tr/td[@headers='date-" + detailId + "']/string()");
 
     QStringList dateResults;
     if (!query.evaluateTo(&dateResults))
@@ -378,7 +383,7 @@ DetailResultInfo parserSbbCh::getJourneyDetailsData(QString queryUrl)
 
 ResultInfo parserSbbCh::parseJourneyData(QByteArray data)
 {
-    QRegExp regexp = QRegExp("<form name=\"tp_results_form\" action=\"(.*)\" method=\"post\" style=\"display:inline;\">(.*)<table cellspacing=\"0\" class=\"hafas-content hafas-tp-result-overview\">(.*)</table>(.*)<table class=\"hafas-content\"");
+    QRegExp regexp = QRegExp("<form name=\"formular\" action=\"(.*)\" method=\"post\" style=\"display:inline;\">(.*)<table cellspacing=\"0\" class=\"hafas-content hafas-tp-result-overview\">(.*)</table>(.*)<table class=\"hafas-content\"");
     regexp.setMinimal(true);
 
     regexp.indexIn(data);
@@ -406,7 +411,7 @@ ResultInfo parserSbbCh::parseJourneyData(QByteArray data)
     QXmlQuery query;
     query.bindVariable("path", &readBuffer);
     //Query for more than one result
-    query.setQuery("declare default element namespace \"http://www.w3.org/1999/xhtml\"; declare variable $path external; doc($path)/html/body/table/tr/td/input[@type='checkbox']/@name/string()");
+    query.setQuery("declare default element namespace \"http://www.w3.org/1999/xhtml\"; declare variable $path external; doc($path)/html/body/table/tr/td/span/@id/string()");
 
     QStringList detailIdResult;
     if (!query.evaluateTo(&detailIdResult))
@@ -446,7 +451,7 @@ ResultInfo parserSbbCh::parseJourneyData(QByteArray data)
         qDebug() << "parserSbbCh::parseJourneyData - Query 5 Failed";
     }
 
-    query.setQuery("declare default element namespace \"http://www.w3.org/1999/xhtml\"; declare variable $path external; doc($path)/html/body/table/tr/td[@headers='location']/string()");
+    query.setQuery("declare default element namespace \"http://www.w3.org/1999/xhtml\"; declare variable $path external; doc($path)/html/body/table/tr/td[@headers='location'][@class!='result maplink']/string()");
 
     QStringList fromToResults;
     if (!query.evaluateTo(&fromToResults))
@@ -462,7 +467,7 @@ ResultInfo parserSbbCh::parseJourneyData(QByteArray data)
         qDebug() << "parserSbbCh::parseJourneyData - Query 7 Failed";
     }
 
-    /*
+/*
     qDebug() <<detailIdResult;
     qDebug() <<fromToResults;
     qDebug() <<timelinkResults;
@@ -470,7 +475,7 @@ ResultInfo parserSbbCh::parseJourneyData(QByteArray data)
     qDebug() <<changesResults;
     qDebug() <<trainsResults;
     qDebug() <<dateResults;
-    */
+*/
 
     ResultInfo result;
 
@@ -488,6 +493,12 @@ ResultInfo parserSbbCh::parseJourneyData(QByteArray data)
     int i;
     for(i=0; i < detailIdResult.count(); i++)
     {
+        QString detailId = detailIdResult[i];
+
+        QRegExp detailIdReg = QRegExp("connectionNumber(.*)");
+        detailIdReg.setMinimal(true);
+        detailId.replace(detailIdReg, "");
+
         ResultItem item;
         item.changes    = changesResults[i];
         item.duration   = durationsResults[i];
@@ -495,7 +506,7 @@ ResultInfo parserSbbCh::parseJourneyData(QByteArray data)
         item.trainType  = trainsResults[i];
         item.fromTime   = timelinkResults[(i * 2)];
         item.toTime     = timelinkResults[(i * 2) + 1];
-        item.detailsUrl = baseUrl + "&" + detailIdResult[i] + "=yes&jumpToDetails=yes&guiVCtrl_connection_detailsOut_add_selection=Details+for+selected";
+        item.detailsUrl = baseUrl + "&HWAI=CONNECTION$" + detailId + "!id=" + detailId + "!HwaiConId=" + detailId + "!HwaiDetailStatus=details";
         result.items.append(item);
     }
     return result;
